fcb = {}
fcb.MOD_NAME = g_currentModName

local BELT_SPEED_MULTIPLIER = 3

function fcb.prerequisitesPresent(specializations)
  -- Must have Dischargeable as specialization to be able to increase its emptySpeed value
  return SpecializationUtil.hasSpecialization(Dischargeable, specializations)
end

function fcb.registerEventListeners(vehicleType)
  SpecializationUtil.registerEventListener(vehicleType, "onPreLoad", fcb)
end

function fcb:onPreLoad()
  -- Override loadDischargeNode
  if self.loadDischargeNode ~= nil then
    self.loadDischargeNode = Utils.overwrittenFunction(self.loadDischargeNode, fcb.loadDischargeNode)
  end

  -- First check if the unit also has a "shovel" (picking up stuff)
  if SpecializationUtil.hasSpecialization(Shovel, self.specializations) then
    -- If so, override the loadShovelNode
    if self.loadShovelNode ~= nil then
      self.loadShovelNode = Utils.overwrittenFunction(self.loadShovelNode, fcb.loadShovelNode)
    end
  end
end

function fcb:loadDischargeNode(superFunc, xmlFile, key, entry)
  -- Get the previous value
  local oldEmptySpeed = xmlFile:getValue(key .. "#emptySpeed", nil)

  -- Make sure we actually got it
  if oldEmptySpeed ~= nil then
    -- Calculate a new value
    local newEmptySpeed = oldEmptySpeed * BELT_SPEED_MULTIPLIER
    -- Store it back
    xmlFile:setFloat(key .. "#emptySpeed", newEmptySpeed)
    -- Save it in a variable so it can be used for any eventual shovel nodes
    fcb.newEmptySpeed = newEmptySpeed
    -- print(FSBaseMission:getVehicleName(self) .. ": " .. oldEmptySpeed .. " -> " .. newEmptySpeed);
  end

  return superFunc(self, xmlFile, key, entry)
end

function fcb:loadShovelNode(superFunc, xmlFile, key, shovelNode)
  -- Get the previous value
  local oldFillSpeed = xmlFile:getValue(key .. "#fillLitersPerSecond", nil)

  -- Make sure we actually got it
  if oldFillSpeed ~= nil then
    -- Store a temp variable
    local newFillSpeed = math.huge

    -- See if we have the empty speed available
    if fcb.newEmptySpeed ~= nil then
      -- Make sure it's at least as big as the fill speed
      newFillSpeed = math.max(oldFillSpeed, fcb.newEmptySpeed)
    else
      -- If the value wasn't available, just multiply it by the same factor
      newFillSpeed = oldFillSpeed * BELT_SPEED_MULTIPLIER
    end

    -- Store it back
    xmlFile:setFloat(key .. "#fillLitersPerSecond", newFillSpeed)
  end

  return superFunc(self, xmlFile, key, shovelNode)
end
